==> kubernetes-model-batch-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/JobConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class JobConditionBuilder extends io.fabric8.kubernetes.api.model.batch.v1.JobConditionFluentImpl<io.fabric8.kubernetes.api.model.batch.v1.JobConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.batch.v1.JobCondition,io.fabric8.kubernetes.api.model.batch.v1.JobConditionBuilder>{
  public JobConditionBuilder() {
    this(false);
  }
  public JobConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(io.fabric8.kubernetes.api.model.batch.v1.JobConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public JobConditionBuilder(io.fabric8.kubernetes.api.model.batch.v1.JobConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(io.fabric8.kubernetes.api.model.batch.v1.JobConditionFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1.JobCondition instance) {
    this(fluent, instance, false);
  }
  public JobConditionBuilder(io.fabric8.kubernetes.api.model.batch.v1.JobConditionFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1.JobCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public JobConditionBuilder(io.fabric8.kubernetes.api.model.batch.v1.JobCondition instance) {
    this(instance,false);
  }
  public JobConditionBuilder(io.fabric8.kubernetes.api.model.batch.v1.JobCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.batch.v1.JobConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.batch.v1.JobCondition build() {
    JobCondition buildable = new JobCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JobConditionBuilder that = (JobConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-batch-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/JobConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JobConditionBuilder extends JobConditionFluentImpl<JobConditionBuilder> implements VisitableBuilder<JobCondition,JobConditionBuilder>{
  public JobConditionBuilder() {
    this(false);
  }
  public JobConditionBuilder(Boolean validationEnabled) {
    this(new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance) {
    this(fluent, instance, false);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastProbeTime(instance.getLastProbeTime()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public JobConditionBuilder(JobCondition instance) {
    this(instance,false);
  }
  public JobConditionBuilder(JobCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastProbeTime(instance.getLastProbeTime()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  JobConditionFluent<?> fluent;
  Boolean validationEnabled;
  public JobCondition build() {
    JobCondition buildable = new JobCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
